@@ -4,7 +4,7 @@ import multiprocessing
 import pickle
 import shutil
 from typing import List
-
+import traceback
 import lightkurve
 import pandas
 import wotan
@@ -257,7 +257,7 @@ class Sherlock:
                     self.__analyse(sherlock_target, time, lcs, flux_err, lc_build.star_info, id_run,
                                    lc_build.transits_min_count, lc_build.cadence, self.report[sherlock_id], wl,
                                    period_grid, lc_build.detrend_period)
-                all_nan_results = len(np.argwhere(np.isnan(signal_selection.transit_result.t0s)).flatten()) == 0
+                all_nan_results = len(np.argwhere(~np.isnan(signal_selection.transit_result.t0s)).flatten()) == 0
                 if not all_nan_results:
                     for index in np.arange(len(signal_selection.transit_result.t0s)):
                         transits_stats_df = transits_stats_df.append({'candidate': str(int(id_run - 1)),
@@ -282,6 +282,8 @@ class Sherlock:
                 object_report["duration"] = signal_selection.transit_result.duration * 60 * 24
                 object_report["t0"] = signal_selection.transit_result.t0
                 object_report["depth"] = signal_selection.transit_result.depth
+                object_report["depth_err"] = signal_selection.transit_result.depth_err
+                object_report["depth_sig"] = signal_selection.transit_result.depth / signal_selection.transit_result.depth_err
                 if signal_selection.transit_result is not None and signal_selection.transit_result.results is not None\
                         and not all_nan_results:
                     object_report['rp_rs'] = signal_selection.transit_result.results.rp_rs
@@ -309,8 +311,9 @@ class Sherlock:
                 self.report[sherlock_id].append(object_report)
                 self.__setup_object_report_logging(sherlock_id, True)
                 logging.info("Listing most promising candidates for ID %s:", sherlock_id)
-                logging.info("%-12s%-10s%-10s%-10s%-8s%-8s%-8s%-8s%-14s%-14s%-12s%-25s%-10s%-18s%-20s", "Detrend no.", "Period",
-                             "Per_err", "Duration", "T0", "Depth", "SNR", "SDE", "Border_score", "Matching OI", "Harmonic",
+                logging.info("%-12s%-10s%-10s%-10s%-8s%-8s%-11s%-11s%-8s%-8s%-14s%-14s%-12s%-25s%-10s%-18s%-20s",
+                             "Detrend no.", "Period", "Per_err", "Duration", "T0", "Depth", "Depth_err", "Depth_sig",
+                             "SNR", "SDE", "Border_score", "Matching OI", "Harmonic",
                              "Planet radius (R_Earth)", "Rp/Rs", "Semi-major axis", "Habitability Zone")
                 if sherlock_id in self.report:
                     candidates_df = pandas.DataFrame(columns=['curve', 'period', 'per_err', 'duration', 't0', 'depth',
@@ -327,21 +330,20 @@ class Sherlock:
                             report['rad_p'] = np.nan
                         else:
                             report['rad_p'] = self.__calculate_planet_radius(lc_build.star_info, report["depth"])
-                        logging.info("%-12s%-10.4f%-10.5f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-14.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s",
+                        logging.info("%-12s%-10.4f%-10.5f%-10.2f%-8.2f%-8.3f%-11.3f%-11.3f%-8.2f%-8.2f%-14.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s",
                                      report["curve"], report["period"], report["per_err"],
-                                     report["duration"], report["t0"], report["depth"], report["snr"], report["sde"],
+                                     report["duration"], report["t0"], report["depth"], report["depth_err"],
+                                     report["depth_sig"], report["snr"], report["sde"],
                                      report["border_score"], report["oi"], report["harmonic"],
                                      report['rad_p'], report['rp_rs'], a, habitability_zone)
                         candidates_df = candidates_df.append(report, ignore_index=True)
                         i = i + 1
                     candidates_df.to_csv(object_dir + "candidates.csv", index=False)
-        except InvalidNumberOfSectorsError as e:
-            logging.exception(str(e))
-            print(e)
+        except InvalidNumberOfSectorsError:
+            logging.exception("Invalid number of sectors exception")
             self.__remove_object_dir(sherlock_id)
         except Exception as e:
-            logging.exception(str(e))
-            print(e)
+            logging.exception("Unexpected exception")
 
     def noise(self, time, flux, signal_power):
         from scipy.signal import periodogram, welch
@@ -378,6 +380,8 @@ class Sherlock:
         return dir + "/"
 
     def __setup_logging(self):
+        if not isinstance(logging.root, logging.RootLogger):
+            logging.root = logging.RootLogger(logging.INFO)
         logging.captureWarnings(True)
         formatter = logging.Formatter(fmt='%(asctime)s %(levelname)-8s %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         logger = logging.getLogger()
@@ -390,6 +394,8 @@ class Sherlock:
         logger.addHandler(handler)
 
     def __setup_object_logging(self, object_id, clean_dir=True):
+        if not isinstance(logging.root, logging.RootLogger):
+            logging.root = logging.RootLogger(logging.INFO)
         object_dir = self.__init_object_dir(object_id, clean_dir)
         logger = logging.getLogger()
         while len(logger.handlers) > 1:
@@ -402,6 +408,8 @@ class Sherlock:
         return object_dir
 
     def __setup_object_report_logging(self, object_id, clean=False):
+        if not isinstance(logging.root, logging.RootLogger):
+            logging.root = logging.RootLogger(logging.INFO)
         object_dir = self.__setup_object_logging(object_id, False)
         logger = logging.getLogger()
         logger.handlers.pop()
@@ -449,7 +457,8 @@ class Sherlock:
         logging.info('Threshold limit for SDE: %.1f', sherlock_target.sde_min)
         if object_info.outliers_sigma:
             logging.info('Sigma threshold for upper outliers clipping: %.1f', object_info.outliers_sigma)
-        logging.info('Sigma threshold for lower outliers clipping: %.1f', object_info.lower_outliers_sigma)
+        if object_info.lower_outliers_sigma:
+            logging.info('Sigma threshold for lower outliers clipping: %.1f', object_info.lower_outliers_sigma)
         logging.info("Fit method: %s", sherlock_target.fit_method)
         if sherlock_target.oversampling is not None:
             logging.info('Oversampling: %.3f', sherlock_target.oversampling)
@@ -672,10 +681,10 @@ class Sherlock:
                            cadence, report, period_grid, detrend_source_period):
         object_info = sherlock_target.object_info
         detrend_logging_customs = 'ker_size' if sherlock_target.detrend_method == 'gp' else "win_size"
-        logging.info("%-12s%-12s%-10s%-8s%-18s%-14s%-14s%-12s%-12s%-16s%-14s%-12s%-25s%-10s%-18s%-20s",
-                     detrend_logging_customs, "Period", "Per_err", "N.Tran", "Mean Depth (ppt)", "T. dur (min)", "T0",
-                     "SNR", "SDE", "Border_score", "Matching OI", "Harmonic", "Planet radius (R_Earth)", "Rp/Rs",
-                     "Semi-major axis", "Habitability Zone")
+        logging.info("%-12s%-12s%-10s%-8s%-18s%-12s%-12s%-14s%-14s%-12s%-12s%-16s%-14s%-12s%-25s%-10s%-18s%-20s",
+                     detrend_logging_customs, "Period", "Per_err", "N.Tran", "Mean Depth (ppt)", 'Depth_err',
+                     'Depth_sig', "T. dur (min)", "T0", "SNR", "SDE", "Border_score", "Matching OI", "Harmonic",
+                     "Planet radius (R_Earth)", "Rp/Rs", "Semi-major axis", "Habitability Zone")
         transit_results = {}
         plot_dir = self.__init_object_run_dir(star_info.object_id, id_run)
         if not sherlock_target.ignore_original:
@@ -686,9 +695,10 @@ class Sherlock:
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
             oi = self.__find_matching_oi(object_info, transit_result.period, transit_result.t0)
-            logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
+            logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-12.3f%-12.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          "PDCSAP_FLUX", transit_result.period,
-                         transit_result.per_err, transit_result.count, transit_result.depth,
+                         transit_result.per_err, transit_result.count, transit_result.depth, transit_result.depth_err,
+                         transit_result.depth / transit_result.depth_err,
                          transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
                          transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
                          habitability_zone)
@@ -702,7 +712,7 @@ class Sherlock:
             save_transit_plot(star_info.object_id, plot_title, plot_dir, plot_file, time, lcs[0], transit_result,
                               cadence, id_run, sherlock_target.use_harmonics_spectra)
         else:
-            transit_result = TransitResult(None, None, 0, 0, 0, 0, [], [], 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, [], False)
+            transit_result = TransitResult(None, None, 0, 0, 0, 0, [], [], 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, [])
         transit_results[0] = transit_result
         for i in range(1, len(wl)):
             transit_result = self.__adjust_transit(sherlock_target, time, lcs[i], star_info, transits_min_count,
@@ -713,9 +723,10 @@ class Sherlock:
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
             oi = self.__find_matching_oi(object_info, transit_result.period, transit_result.t0)
-            logging.info('%-12.4f%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
+            logging.info('%-12.4f%-12.5f%-10.6f%-8s%-18.3f%-12.3f%-12.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          wl[i], transit_result.period,
-                     transit_result.per_err, transit_result.count, transit_result.depth,
+                     transit_result.per_err, transit_result.count, transit_result.depth, transit_result.depth_err,
+                         transit_result.depth / transit_result.depth_err,
                      transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
                          transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
                      habitability_zone)
@@ -769,14 +780,16 @@ class Sherlock:
         if sherlock_target.custom_transit_template is not None:
             power_args["transit_template_generator"] = sherlock_target.custom_transit_template
         results = model.power(**power_args)
+        depths = (1 - results.transit_depths) * 1000
+        depths_err = results.transit_depths_uncertainties * 1000
         if results.T0 != 0:
-            depths = results.transit_depths[~np.isnan(results.transit_depths)]
-            depth = (1. - np.mean(depths)) * 1000
+            depths_calc = results.transit_depths[~np.isnan(results.transit_depths)]
+            depth = (1. - np.mean(depths_calc)) * 1000
+            depth_err = np.sqrt(np.nansum([depth_err ** 2 for depth_err in depths_err])) / len(depths_err)
         else:
             t0s = results.transit_times
             depth = results.transit_depths
-        depths = (1 - results.transit_depths) * 1000
-        depths_err = results.transit_depths_uncertainties * 1000
+            depth_err = np.nan
         t0s = np.array(results.transit_times)
         in_transit = tls.transit_mask(time, results.period, results.duration, results.T0)
         transit_count = results.distinct_transit_count
@@ -791,7 +804,7 @@ class Sherlock:
         harmonic = self.__is_harmonic(results, run_results, report, detrend_source_period)
         harmonic_power = harmonic_spectrum(results['periods'], results.power)
         return TransitResult(power_args, results, results.period, results.period_uncertainty, duration,
-                             results.T0, t0s, depths, depths_err, depth, results.odd_even_mismatch,
+                             results.T0, t0s, depths, depths_err, depth, depth_err, results.odd_even_mismatch,
                              (1 - results.depth_mean_even[0]) * 1000, (1 - results.depth_mean_odd[0]) * 1000, transit_count,
                              results.snr, results.SDE, results.FAP, border_score, in_transit, harmonic,
                              harmonic_power)
@@ -802,7 +815,7 @@ class Sherlock:
             rp = star_info.radius * math.sqrt(depth / 1000) / 0.0091577
         except ValueError as e:
             logging.error("Planet radius could not be calculated: depth=%s, star_radius=%s", depth, star_info.radius)
-            logging.exception(str(e))
+            logging.exception("Planet radius could not be calculated")
             print(e)
         return rp
 
